# pyautd3_link_ethercrab

![build](https://github.com/shinolab/pyautd3_link_ethercrab/workflows/build/badge.svg)
[![codecov](https://codecov.io/gh/shinolab/pyautd3_link_ethercrab/graph/badge.svg?precision=2)](https://codecov.io/gh/shinolab/pyautd3_link_ethercrab)
[![PyPI version](https://img.shields.io/pypi/v/pyautd3_link_ethercrab)](https://pypi.org/project/pyautd3_link_ethercrab/)

[autd3-link-ethercrab](https://github.com/shinolab/autd3-rs) wrapper library for python3.12+

## Install

```
pip install pyautd3_link_ethercrab
```

## Example

see [example](./example)

## LICENSE

MIT

This library depends on some third-party libraries. Please check their licenses in the `ThirdPartyNotices.txt` in the distributed package.

# Author

Shun Suzuki, 2025
